/*
   REPPURGE.PRG

   FOR ClReport users

   PURPOSE: Simple utility to remove the database fields defined
   in the field list and not used in the report layout.


   PARAMETERS: cRepLib  : name of the report lib. Default ext .CLR
               cRepName : name of the report.
                          Optional. If not passed, all reports will
                          be purged


   COMPILE: /a/m/n/w
   LINK: standalone, standard Clipper libs

   Author : Vicente Vila - CIS 100020,1755
            TeGo
            Marbella (Spain)

   Donated to the cause of the ClReport users ...<g>


   NOTE : ClReport stores in the field <Field_No> the position in
   the report layout. If the field doesn't appear in the layout, it
   stores 0 in it.

     If you use to load all the fields of a database then there will
   be many database fields defined in the report with <Field_No> = 0,
   when ClReport only needs to have defined the ones that appear in
   the layout and/or the calculated fields ...

     These utility just do a DELETE ALL FOR ! Empty( Dbf_Alias ) -
   the _database_ fields - .AND. field_no = 0.

     It makes more readable the field list and the .CLR file smaller.
   Hope you find it useful !

*/

#define ADD_EXT( cFile, cExt )  (IF("." $ cFile, cFile, RTrim(cFile)+cExt ))
#define TRIM_EXT( cFile )       (IF("." $ cFile, Left(cFile,At(".",cFile)-1), cFile ))

#define DBF_SIZE()              (1+Header()+RecCount()*RecSize())

PROC RepPurge( cRepLib, cRepName )

  LOCAL bFor, bWhile
  LOCAL nOldSize

  FIELD Report, Field_No, Dbf_Alias

  IF cRepLib = NIL
    ? "Usage : RepPurge <reportLibName> [<reportName>]"
    ?
    QUIT
  ENDIF


  USE (ADD_EXT(cRepLib,".CLR")) NEW INDEX (TRIM_EXT(cRepLib)) EXCLUSIVE
  ? "Processing ..."

  bFor   := {|| ! Empty( Dbf_Alias ) .AND. Field_No = 0 }
  bWhile := IF( cRepName = NIL, {|| .T. }, {|| Report = Upper( cRepName ) } )

  IF cRepName != NIL
    IF ! DbSeek( Upper( cRepName ) )
      ? "Report "+cRepName+" not found !"
    ENDIF
  ENDIF

  DbEval( {|| DbDelete() }, bFor, bWhile )

  nOldSize := DBF_SIZE()

  PACK

  ?? " Done. ", Int(DBF_SIZE()/nOldSize*100), "%"

RETURN







